% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{stdEr}
\alias{stdEr}
\title{Generic Standard Error Function}
\usage{
stdEr(object, ...)
}
\arguments{
\item{object}{An object of class \code{mle_adapt_fit}.}

\item{...}{Additional arguments.}
}
\value{
A numeric vector of standard errors.
}
\description{
Generic Standard Error Function
}
