% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{AIC.mle_adapt_fit}
\alias{AIC.mle_adapt_fit}
\title{Generic AIC Function for mle_adapt_fit}
\usage{
\method{AIC}{mle_adapt_fit}(object, ..., k = 2)
}
\arguments{
\item{object}{An object of class \code{mle_adapt_fit}.}

\item{...}{Additional arguments.}

\item{k}{Penalty parameter, default is 2.}
}
\value{
A numeric value representing AIC.
}
\description{
Generic AIC Function for mle_adapt_fit
}
